@@ -3,7 +3,7 @@
     author: Glen Swinfield <glen.swinfied@gmail.com>
     license: see LICENSE """
 
-import os
+from os import path, makedirs, system
 import shutil
 import datetime
 
@@ -40,23 +40,26 @@ class Jinja2Compiler(Compiler):
         cl = ChoiceLoader([FileSystemLoader(site.templatedir)])
         self.env = Environment(loader=cl, extensions=[FragmentCacheExtension])
         self.env.fragment_cache = SimpleCache()
-        self.env.globals.update({'global': site.config.get('global'), 'datetime': datetime.datetime})
+        if 'global' in site.config:
+            self.env.globals.update({
+                'global': site.config.get('global')})
+        self.env.globals.update({'datetime': datetime.datetime})
 
     def _generate_content_lists(self):
         """
-        Loop over the site content and generate a list of content object,
-        and a list of non content objcts (e.g .txt. files)
+        Loop over the site content and generate a list of content objects and
+        a list of non content objects (e.g .txt. files)
         Returns a dict {'contents': [], 'noncontents': []}
         """
         contents = []
         noncontents = []
         for paths in self.site.content:
             try:
-                content = create_content(self.parser, paths.get('full_path'), paths.get('split_path'))
+                content = create_content(self.parser, paths)
                 contents.append(content)
-                dst_file = os.path.join(self.site.destdir, content.filename)
-                if not os.path.exists(os.path.dirname(dst_file)):
-                    os.makedirs(os.path.dirname(dst_file))
+                dst_file = path.join(self.site.destdir, content.filename)
+                if not path.exists(path.dirname(dst_file)):
+                    makedirs(path.dirname(dst_file))
             except InvalidContentTypeError:
                 noncontents.append({
                         'full_path': paths.get('full_path'),
@@ -66,13 +69,15 @@ class Jinja2Compiler(Compiler):
 
     def compile(self, less):
         """
+        Take the contents of the site and compie it into .html files
+        Copy across all non markdown files as-is
         """
         noncontents, contents = self._generate_content_lists().values()
         contentfilter = Filter(filter(lambda x: isinstance(x, Post), contents))
         t = len(contents)
         built = []
         for content in contents:
-            dst_file = os.path.join(self.site.destdir, content.filename)
+            dst_file = path.join(self.site.destdir, content.filename)
             template_obj = self.env.get_template(content.template)
             data = content.templatedata
             data.update({'posts': contentfilter})
@@ -82,16 +87,16 @@ class Jinja2Compiler(Compiler):
                 built.append(content.filename)
 
         for noncontent in noncontents:
-            dst_file = os.path.join(self.site.destdir, noncontent.get('split_path'))
+            dst_file = path.join(self.site.destdir, noncontent.get('split_path'))
             shutil.copyfile(noncontent.get('full_path'), dst_file)
 
         if less is True:
-            less_config = self.site.config.get('less')
-            less_com = "lessc %s > %s -x" % (less_config.get('src'), less_config.get('dst'))
-            # should use subprocess.call here but it's throwing a weird bug
-            os.system(less_com)
+            cmd = "lessc %s > %s -x"
+            lesscnf = self.site.config.get('less')
+            lesscom = cmd % (lesscnf.get('src'), lesscnf.get('dst'))
+            system(lesscom)
 
-        if os.path.exists(self.site.deststaticdir):
+        if path.exists(self.site.deststaticdir):
             shutil.rmtree(self.site.deststaticdir)
         shutil.copytree(self.site.staticdir, self.site.deststaticdir)
 
