@@ -10,7 +10,9 @@ import markdown
 from datetime import datetime
 
 
-def create_content(parser, full_path, split_path):
+def create_content(parser, paths):
+    full_path = paths.get('full_path')
+    split_path = paths.get('split_path')
     base = os.path.basename(full_path)
     ext = os.path.splitext(base)[1]
     if ext != '.md':
