@@ -5,6 +5,7 @@
 
 import os
 import yaml
+from stanley import touch
 
 
 class Site(object):
@@ -13,8 +14,7 @@ class Site(object):
     """
     def __init__(self, config_file):
         if not os.path.exists(config_file):
-            f = open(config_file, 'w+')
-            f.close()
+            touch(config_file)
         self.config = config_file
         self._root = os.path.dirname(config_file)
         self._content = []
